@@ -13,9 +13,10 @@ reliability <- function(seminr_model) {
   #get HOC
   model_constructs <- constructs_in_model(seminr_model)
   alpha <- cronbachs_alpha(seminr_model, model_constructs$construct_names)
-  mat1 <- rhoC_AVE_pls_model(seminr_model, model_constructs$construct_names)
+  mat1 <- rhoC_AVE_pls_model(pls_model = seminr_model, constructs = model_constructs$construct_names)
   mat2 <- rho_A(seminr_model, model_constructs$construct_names)
   table <- cbind(alpha, mat1, mat2)
+  colnames(table) <- c("alpha", "rhoC",   "AVE",  "rhoA")
   comment(table) <- "Alpha, rhoC, and rhoA should exceed 0.7 while AVE should exceed 0.5"
   class(table) <- append(class(table), c("table_output","reliability_table"))
   return(table)
